# Changelog

All notable changes to this project will be documented in this file.

## [unreleased]

### 🚀 Features

- Add s3 support on cli (table-version)
- Add s3 cli parameters to remaining commands

### 🐛 Bug Fixes

- Remove logs for cli runner's sake
- Add condition on table_type for cli

### 📚 Documentation

- Add CHANGELOG
- Update changelog
- Update README
- Update readme
- Update Readme
- Update readme
- Update todo commands in readme
- Update readme

### ⚙️ Miscellaneous Tasks

- Bump version
- Version mgmt
- Bump version
- Bump version

<!-- generated by git-cliff -->
